# pysorteddict

Enriches Python with `SortedDict`, a sorted dictionary: a dictionary in which the keys are always in ascending order.

pysorteddict is implemented entirely in C++. `SortedDict` provides a Python interface to `std::map`.

:::{toctree}
:hidden:

installation
usage
documentation
performance
changelog
development
:::

<!--
Putting an HTML tag in a Markdown link containing an image is probably not a
good idea. Nesting inline attributes (a MyST Parser extension currently in
beta) probably isn't, either. The HTML document is generated exactly as
desired, though.
-->
[
[[![installation](_static/images/installation.svg)<br>Installation](installation)]{.card}
[[![usage](_static/images/usage.svg)<br>Usage](usage)]{.card}
[[![documentation](_static/images/documentation.svg)<br>Documentation](documentation)]{.card}
[[![performance](_static/images/performance.svg)<br>Performance](performance)]{.card}
[[![changelog](_static/images/changelog.svg)<br>Changelog](changelog)]{.card}
[[![development](_static/images/development.svg)<br>Development](development)]{.card}
]{.card-container}
